==> mesido-0.0.2.dev0-py3-none-any.whl: mesido/pycml/component_library/milp/electricity/electricity_cable.py <==
from numpy import nan

from mesido.pycml import Variable

from .electricity_base import ElectricityTwoPort
from .._internal import BaseAsset


class ElectricityCable(ElectricityTwoPort, BaseAsset):
    """
    The electricity cable component is used to model voltage and power drops in the electricity
    lines. We model the power losses by over estimating them with the maximum current. We ensure
    that the power is always less than what the current is able to carry by an equality constraint
    at the demand where we enforce the minimum voltage.
    """

    def __init__(self, name, **modifiers):
        super().__init__(name, **modifiers)

        self.component_type = "electricity_cable"
        self.disconnectable = False

        self.length = 1.0

        # Powerloss with inequality in the milp-mixin
        # values for NAYY 4x50 SE
        # from: https://pandapower.readthedocs.io/en/v2.6.0/std_types/basic.html
        self.max_current = nan
        self.min_voltage = nan
        self.max_voltage = self.min_voltage * 2.0
        self.nominal_current = nan
        self.nominal_voltage = nan
        self.r = 1.0e-6 * self.length  # TODO: temporary value
        self.nominal_voltage_loss = (self.nominal_current * self.r * self.nominal_current) ** 0.5
        self.add_variable(Variable, "Power_loss", min=0.0, nominal=self.r * self.max_current ** 2)
        self.add_variable(Variable, "I", nominal=self.nominal_current)
        self.add_variable(Variable, "V_loss", nominal=self.nominal_voltage_loss)

        # TODO: if one wants to include the option for cable_voltage_losses to be false as with
        #  cable_power_losses, then the next equation and V_loss variable instantiation should move
        #  to electricity_physics_mixin, to ensure proper scaling.
        self.add_equation(
            (
                (self.ElectricityOut.V - (self.ElectricityIn.V - self.V_loss))
                / self.nominal_voltage_loss
            )
        )
        self.add_equation(((self.ElectricityIn.I - self.ElectricityOut.I) / self.nominal_current))
        self.add_equation(((self.ElectricityIn.I - self.I) / self.nominal_current))
        self.add_equation(
            (
                (self.ElectricityOut.Power - (self.ElectricityIn.Power - self.Power_loss))
                / (self.nominal_voltage * self.nominal_current * self.r * self.max_current) ** 0.5
            )
        )

==> mesido-0.1.8.5-py3-none-any.whl: mesido/pycml/component_library/milp/electricity/electricity_cable.py <==
from mesido.pycml import Variable

from numpy import nan

from .electricity_base import ElectricityTwoPort
from .._internal import BaseAsset


class ElectricityCable(ElectricityTwoPort, BaseAsset):
    """
    The electricity cable component is used to model voltage and power drops in the electricity
    lines. We model the power losses by over estimating them with the maximum current. We ensure
    that the power is always less than what the current is able to carry by an equality constraint
    at the demand where we enforce the minimum voltage.
    """

    def __init__(self, name, **modifiers):
        super().__init__(name, **modifiers)

        self.component_type = "electricity_cable"
        self.disconnectable = False

        self.length = 1.0

        # Powerloss with inequality in the milp-mixin
        # values for NAYY 4x50 SE
        # from: https://pandapower.readthedocs.io/en/v2.6.0/std_types/basic.html
        self.max_current = nan
        self.min_voltage = nan
        self.max_voltage = self.min_voltage * 2.0
        self.nominal_current = nan
        self.nominal_voltage = nan
        self.r = 1.0e-6 * self.length  # TODO: temporary value
        self.nominal_voltage_loss = (self.nominal_current * self.r * self.nominal_voltage) ** 0.5
        self.power_loss_nominal = self.r * self.max_current * self.nominal_current
        # We accept lower accuracy in the loss computation to improve scaling in case the nominals
        # are very far apart. Typically, when a short cable has a very high max capacity.
        if self.power_loss_nominal / self.ElectricityIn.Power.nominal < 1.0e-4:
            self.power_loss_nominal = self.ElectricityIn.Power.nominal * 1.0e-4
        self.add_variable(Variable, "Power_loss", min=0.0, nominal=self.power_loss_nominal)
        self.add_variable(Variable, "I", nominal=self.nominal_current)
        self.add_variable(Variable, "V_loss", nominal=self.nominal_voltage_loss)

        # TODO: if one wants to include the option for cable_voltage_losses to be false as with
        #  cable_power_losses, then the next equation and V_loss variable instantiation should move
        #  to electricity_physics_mixin, to ensure proper scaling.
        self.add_equation(
            (
                (self.ElectricityOut.V - (self.ElectricityIn.V - self.V_loss))
                / self.nominal_voltage_loss
            )
        )
        self.add_equation(((self.ElectricityIn.I - self.ElectricityOut.I) / self.nominal_current))
        self.add_equation(((self.ElectricityIn.I - self.I) / self.nominal_current))
        self.add_equation(
            (
                (self.ElectricityOut.Power - (self.ElectricityIn.Power - self.Power_loss))
                / (self.ElectricityIn.Power.nominal * self.Power_loss.nominal) ** 0.5
            )
        )
